
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : pro-2varstat-menu.scm
;; DESCRIPTION : pro-2varstat menu
;; COPYRIGHT   : Emmanuel Corcelle (corcelle at gmail dot com)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; BASED ON    : giac-menus.scm
;; COPYRIGHT   : (C) 1999  Bernard Parisse and Joris van der Hoeven
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(texmacs-module (pro-2varstat-menu))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Insert professor primitive
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (professor-cursor-pos l)
  (cond ((null? l) 0)
	((null? (cdr l)) 1)
	((and (== (car l) #\() (== (cadr l) #\))) 1)
	((and (== (car l) #\() (== (cadr l) #\,)) 1)
	((and (== (car l) #\,) (== (cadr l) #\))) 1)
	((and (== (car l) #\,) (== (cadr l) #\,)) 1)
	(else (+ (professor-cursor-pos (cdr l)) 1))))

(define (professor-insert s)
  (insert-go-to s (list (professor-cursor-pos (string->list s)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; pro- menu
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(menu-bind pro-2varstat-menu

  (->"Statistiques a deux variables"

	("Tableau" 
	  (professor-insert "\\\\begin{pro-tabled}{1} ~ ")
	  (insert-return)
	  (professor-insert "[0,5,10,15,20,25,30],    <liste_X> ~ ")
	  (insert-return)
	  (professor-insert "[17,21,25,30,36,42,40]   <liste_Y> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-tabled}"))

	("Parametres de la serie" 
	  (professor-insert "\\\\begin{pro-2varstat}{1} ~ ")
	  (insert-return)
	  (professor-insert "[0,5,10,15,20,25,30],    <liste_X> ~ ")
	  (insert-return)
	  (professor-insert "[17,21,25,30,36,42,40]   <liste_Y> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-2varstat}"))

	("Parametres de la regression lineaire (moindres carres)" 
	  (professor-insert "\\\\begin{pro-linreg}{1} ~ ")
	  (insert-return)
	  (professor-insert "[0,5,10,15,20,25,30],    <liste_X> ~ ")
	  (insert-return)
	  (professor-insert "[17,21,25,30,36,42,40]   <liste_Y> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-linreg}"))

	("Nuage de points" 
	  (professor-insert "\\\\begin{pro-nuage}{1} ~ ")
	  (insert-return)
	  (professor-insert "[0,5,10,15,20,25,30],    <liste_X> ~ ")
	  (insert-return)
	  (professor-insert "[15,19,23,28,34,40,39],  <liste_Y> ~ ")
	  (insert-return)
	  (professor-insert "0,36,0,50,               <xmin,xmax,ymin,ymax> ~ ")
	  (insert-return)
	  (professor-insert "3,5,                     <1cm=ux,1cm=uy> ~ ")
	  (insert-return)
	  (professor-insert "6,10,                    <ecart_legende_x,ecart_legende_y> ~ ")
	  (insert-return)
	  (professor-insert "1,2,                     <ecart_grille_x,ecart_grille_y> ~ ")
	  (insert-return)
	  (professor-insert "[ <___________debut_des_options___________> ~ ")
	  (insert-return)
	  (professor-insert " [\"titre-gauche\",\"Nuage de points\"] ~ ")
	  (insert-return)
	  (professor-insert "] <___________fin_des_options___________> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-nuage}"))

	("Nuage de points, point moyen et droite de regression (moindres carres)" 
	  (professor-insert "\\\\begin{pro-nuage}{1} ~ ")
	  (insert-return)
	  (professor-insert "[0,5,10,15,20,25,30],    <liste_X> ~ ")
	  (insert-return)
	  (professor-insert "[15,19,23,28,34,40,39],  <liste_Y> ~ ")
	  (insert-return)
	  (professor-insert "0,36,0,50,               <xmin,xmax,ymin,ymax> ~ ")
	  (insert-return)
	  (professor-insert "3,5,                     <1cm=ux,1cm=uy> ~ ")
	  (insert-return)
	  (professor-insert "6,10,                    <ecart_legende_x,ecart_legende_y> ~ ")
	  (insert-return)
	  (professor-insert "1,2,                     <ecart_grille_x,ecart_grille_y> ~ ")
	  (insert-return)
	  (professor-insert "[ <___________debut_des_options___________> ~ ")
	  (insert-return)
	  (professor-insert " [\"titre-gauche\",\"Nuage de points\"], ~
 ~ ")
	  (insert-return)
	  (professor-insert " [\"point-moyen\",\"$G$\",\"ulft\",\"rouge\",[\"xy\",\"$@overline{x}$\",\"$@overline{y}$\"]], ~ ")
	  (insert-return)
	  (professor-insert " [\"droite-regression\",\"rouge\"], ~ ")
	  (insert-return)
	  (professor-insert " [\"texte-courbe\",35,\"$({@cal D})$\",\"ulft\",\"rouge\"], ~ ")
	  (insert-return)
	  (professor-insert " [\"point-courbe\",33,\"$B$\",\"lrt\",\"noir\",[\"x\"]]")
	  (insert-return)
	  (professor-insert "] <___________fin_des_options___________> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-nuage}"))

	("Nuage de points et ecarts utilises pour une droite (AB) donnee" 
	  (professor-insert "\\\\begin{pro-nuage}{1} ~ ")
	  (insert-return)
	  (professor-insert "[0,5,10,15,20,25,30],    <liste_X> ~ ")
	  (insert-return)
	  (professor-insert "[15,19,23,28,34,40,39],  <liste_Y> ~ ")
	  (insert-return)
	  (professor-insert "0,36,0,50,               <xmin,xmax,ymin,ymax> ~ ")
	  (insert-return)
	  (professor-insert "3,5,                     <1cm=ux,1cm=uy> ~ ")
	  (insert-return)
	  (professor-insert "6,10,                    <ecart_legende_x,ecart_legende_y> ~ ")
	  (insert-return)
	  (professor-insert "1,2,                     <ecart_grille_x,ecart_grille_y> ~ ")
	  (insert-return)
	  (professor-insert "[ <___________debut_des_options___________> ~ ")
	  (insert-return)
	  (professor-insert " [\"titre-gauche\",\"Nuage de points\"] ~ ")
	  (insert-return)
	  (professor-insert " [\"carres-ecarts\",[0,17],[30,40],\"vert\"] ~ ")
	  (insert-return)
	  (professor-insert "] <___________fin_des_options___________> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-nuage}"))

  )

)
