
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : pro-geometrie-menu.scm
;; DESCRIPTION : pro-geometrie menu
;; COPYRIGHT   : Emmanuel Corcelle (corcelle at gmail dot com)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; BASED ON    : giac-menus.scm
;; COPYRIGHT   : (C) 1999  Bernard Parisse and Joris van der Hoeven
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(texmacs-module (pro-geometrie-menu))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Insert professor primitive
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (professor-cursor-pos l)
  (cond ((null? l) 0)
	((null? (cdr l)) 1)
	((and (== (car l) #\() (== (cadr l) #\))) 1)
	((and (== (car l) #\() (== (cadr l) #\,)) 1)
	((and (== (car l) #\,) (== (cadr l) #\))) 1)
	((and (== (car l) #\,) (== (cadr l) #\,)) 1)
	(else (+ (professor-cursor-pos (cdr l)) 1))))

(define (professor-insert s)
  (insert-go-to s (list (professor-cursor-pos (string->list s)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; pro-geometrie menu
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(menu-bind pro-geometrie-menu

  (->"Geometrie"

	("Cercle circonscrit" 
	  (professor-insert "\\\\begin{pro-cerclecir}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"M\",     <diametre_[AB]__M_sur_cercle> ~ ")
	  (insert-return)
	  (professor-insert "60,              <angle_pour_M> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"      <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-cerclecir} ~ "))

	("Angles inscrit" 
	  (professor-insert "\\\\begin{pro-anginscrit}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"E\",\"F\", <angles_inscrits_AEB_et_AFB> ~ ")
	  (insert-return)
	  (professor-insert "30,100,200,300,  <angles_pour_placer_A,B,E,F> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"      <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-anginscrit} ~ "))

	("Angles au centre" 
	  (professor-insert "\\\\begin{pro-angcentre}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"E\",\"O\",  <angles_inscrit_AEB_et_au_centreAOB> ~ ")
	  (insert-return)
	  (professor-insert "30,100,250,       <angles_pour_placer_A,B,E> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"       <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-angcentre} ~ "))

	---
	("Pythagore" 
	  (professor-insert "\\\\begin{pro-pythagore}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",   <ABC_rectangle_en_A> ~ ")
	  (insert-return)
	  (professor-insert "7,8,0,         <AB,BC,CA_(0_si_on_cherche)> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"    <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-pythagore} ~ "))

	("Reciproque de Pyhagore" 
	  (professor-insert "\\\\begin{pro-recpythagore}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",  <ABC_avec_BC_grand_cote> ~ ")
	  (insert-return)
	  (professor-insert "5,13,12,      <AB,BC,CA> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"   <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-recpythagore} ~ "))

	("Thales" 
	  (professor-insert "\\\\begin{pro-thales}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",\"M\",\"N\",  <M_sur_(AB),N_sur_(AC)> ~ ")
	  (insert-return)
	  (professor-insert "\"papillon\",           <papillon_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"           <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-thales} ~ "))

	("Reciproque de Thales" 
	  (professor-insert "\\\\begin{pro-recthales}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",\"M\",\"N\",  <M_sur_(AB),N_sur_(AC)> ~ ")
	  (insert-return)
	  (professor-insert "\"normal\",             <papillon_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "5,8,4,6.3,            <AM,AB,AN,AC> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"           <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-recthales} ~ "))

	---
	("Trigonometrie" 
	  (professor-insert "\\\\begin{pro-trigo}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",   <ABC_rectangle_en_A> ~ ")
	  (insert-return)
	  (professor-insert "2,             <1_pour_angle(ABC),_2_pour_angle(BCA)> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"    <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-trigo} ~ "))

	("Angles oppose" 
	  (professor-insert "\\\\begin{pro-angoppose}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"P\",\"APR\",\"MPE\",  <sommet,noms_des_angles> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"       <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-angoppose} ~ "))
	("Angles alternes-internes" 
	  (professor-insert "\\\\begin{pro-angaltint}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"BEF\",\"DFB\",   <noms_des_angles> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"    <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-angaltint} ~ "))

	("Angles correspondants" 
	  (professor-insert "\\\\begin{pro-angcorres}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"BEF\",\"DFH\",   <noms_des_angles> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"    <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-angcorres} ~ "))

	---
	("Medianes" 
	  (professor-insert "\\\\begin{pro-medianes}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",   <triangle_ABC> ~ ")
	  (insert-return)
	  (professor-insert "\"I\",\"J\",\"K\",   <medianes_(AI),(BJ),(CK)> ~ ")
	  (insert-return)
	  (professor-insert "\"G\",           <centre_de_gravite> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"    <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-medianes} ~ "))

	("Mediatrices" 
	  (professor-insert "\\\\begin{pro-mediatrices}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",    <triangle_ABC> ~ ")
	  (insert-return)
	  (professor-insert "\"I\",\"J\",\"K\",    <mediatrices<(AI),(BJ),(CK)> ~ ")
	  (insert-return)
	  (professor-insert "\"O\",            <centre_du_cercle_circonscrit> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"     <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-mediatrices} ~ "))

	("Hauteurs" 
	  (professor-insert "\\\\begin{pro-hauteurs}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",    <triangle_ABC> ~ ")
	  (insert-return)
	  (professor-insert "\"L\",\"M\",\"N\",    <hauteurs_(AL),(BM),(CN)> ~ ")
	  (insert-return)
	  (professor-insert "\"H\",            <orthocentre> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"     <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-hauteurs} ~ "))

	("Bissectrices" 
	  (professor-insert "\\\\begin{pro-bissectrices}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",    <triangle_ABC> ~ ")
	  (insert-return)
	  (professor-insert "\"L\",\"M\",\"N\",    <points_de_contact_du_cercle_inscrit> ~ ")
	  (insert-return)
	  (professor-insert "\"I\",            <centre_du_cercle_inscrit> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"     <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-bissectrices} ~ "))

	---
	("Cube" 
	  (professor-insert "\\\\begin{pro-cube}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",\"D\",  <face_avant> ~ ")
	  (insert-return)
	  (professor-insert "\"E\",\"F\",\"G\",\"H\",  <face_arriere> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"       <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-cube} ~ "))

	("Parallelepipede" 
	  (professor-insert "\\\\begin{pro-parallelepipede}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",\"D\",  <face_avant> ~ ")
	  (insert-return)
	  (professor-insert "\"E\",\"F\",\"G\",\"H\",  <face_arriere> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"       <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-parallelepipede} ~ "))

	("Pyramide" 
	  (professor-insert "\\\\begin{pro-pyramide}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",\"D\",  <base> ~ ")
	  (insert-return)
	  (professor-insert "\"S\",\"H\",          <sommet,centre_de_la_base> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"       <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-pyramide} ~ "))

	("Section de pyramide" 
	  (professor-insert "\\\\begin{pro-secpyramide}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"A\",\"B\",\"C\",\"D\",     <base> ~ ")
	  (insert-return)
	  (professor-insert "\"S\",\"H\",             <sommet,centre_de_la_base> ~ ")
	  (insert-return)
	  (professor-insert "1/2,                 <coefficient_de_reduction> ~ ")
	  (insert-return)
	  (professor-insert "\"A'\",\"B'\",\"C'\",\"D'\", <section> ~ ")
	  (insert-return)
	  (professor-insert "\"H'\",                <centre_de_la_section> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"          <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-secpyramide} ~ "))

	("Cone" 
	  (professor-insert "\\\\begin{pro-cone}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"S\",\"O\",\"M\",   <sommet,centre_de_la_base,point_de_la_base> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"    <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-cone} ~ "))

	("Section de cone" 
	  (professor-insert "\\\\begin{pro-seccone}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"S\",\"O\",\"M\",   <sommet,centre_de_la_base,point_de_la_base> ~ ")
	  (insert-return)
	  (professor-insert "1/2,           <coefficient_de_reduction> ~ ")
	  (insert-return)
	  (professor-insert "\"O'\",\"M'\",     <centre_de_la_section,point_de_la_section> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"    <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-seccone} ~ "))

	("Sphere" 
	  (professor-insert "\\\\begin{pro-sphere}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"O\",\"M\",      <centre,point_de_la_sphere> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"   <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-sphere} ~ "))

	("Section de sphere" 
	  (professor-insert "\\\\begin{pro-secsphere}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"O\",           <centre> ~ ")
	  (insert-return)
	  (professor-insert "1/2,           <coefficient> ~ ")
	  (insert-return)
	  (professor-insert "\"O'\",\"M\",      <centre_de_la_section,point_de_la_section> ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"    <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-secsphere} ~ "))

	("Cylindre" 
	  (professor-insert "\\\\begin{pro-cylindre}{1} ~ ")
	  (insert-return)
	  (professor-insert "\"O\",\"M\",      <centre_de_la_base_avant,point_de_la_base_avant> ~ ")
	  (insert-return)
	  (professor-insert "\"O'\",\"M'\",    <centre_de_la_base_arriere,point_de_la_base_arriere> ~")
	  (insert-return)
	  (professor-insert "\"debout\",     <debout ou couche ~ ")
	  (insert-return)
	  (professor-insert "\"mainlevee\"   <mainlevee_ou_normal> ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{pro-cylindre} ~ "))

  )

)
