
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : pro-mat-menu.scm
;; DESCRIPTION : pro-mat menu
;; COPYRIGHT   : Emmanuel Corcelle (corcelle at gmail dot com)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; BASED ON    : giac-menus.scm
;; COPYRIGHT   : (C) 1999  Bernard Parisse and Joris van der Hoeven
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(texmacs-module (pro-mat-menu))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Insert professor primitive
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (professor-cursor-pos l)
  (cond ((null? l) 0)
	((null? (cdr l)) 1)
	((and (== (car l) #\() (== (cadr l) #\))) 1)
	((and (== (car l) #\() (== (cadr l) #\,)) 1)
	((and (== (car l) #\,) (== (cadr l) #\))) 1)
	((and (== (car l) #\,) (== (cadr l) #\,)) 1)
	(else (+ (professor-cursor-pos (cdr l)) 1))))

(define (professor-insert s)
  (insert-go-to s (list (professor-cursor-pos (string->list s)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; pro-mat menu
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(menu-bind pro-mat-menu

  (->"Matrices"

	("Ecrire une matrice" 
	  (professor-insert "\\\\begin{matmat} ~ ")
	  (insert-return)
	  (professor-insert "matmat([[112,2,cos(alpha)], ~ ")
	  (insert-return)
	  (professor-insert "        [sqrt(2),0,1], ~ ")
	  (insert-return)
	  (professor-insert "        [1/2,2,3]]) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{matmat} ~ "))
	---

	("Produit de matrices" 
	  (professor-insert "\\\\begin{promat} ~ ")
	  (insert-return)
	  (professor-insert "promat([[112,2,0], ~ ")
	  (insert-return)
	  (professor-insert "        [0,0,1], ~ ")
	  (insert-return)
	  (professor-insert "        [1,2,3]], ~ ")
	  (insert-return)
	  (professor-insert "[[1], ~ ")
	  (insert-return)
	  (professor-insert " [5], ~ ")
	  (insert-return)
	  (professor-insert " [0]], ~ ")
	  (insert-return)
	  (professor-insert "[[\"R\",\"Z\"]]) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{promat} ~ "))

	("Produit de matrices (avec option trigo)" 
	  (professor-insert "\\\\begin{promat} ~ ")
	  (insert-return)
	  (professor-insert "promat([[cos(theta),-sin(theta),0], ~ ")
	  (insert-return)
	  (professor-insert "        [sin(theta),cos(theta),0], ~ ")
	  (insert-return)
	  (professor-insert "        [0,0,1]], ~ ")
	  (insert-return)
	  (professor-insert "[[cos(theta),-sin(theta),0], ~ ")
	  (insert-return)
	  (professor-insert " [sin(theta),cos(theta),0], ~ ")
	  (insert-return)
	  (professor-insert " [0,0,1]], ~ ")
	  (insert-return)
	  (professor-insert "[[\"R\",\"R\",\"R^2\"],trigo]) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{promat} ~ "))
	---

	("Determinant" 
	  (professor-insert "\\\\begin{detmat} ~ ")
	  (insert-return)
	  (professor-insert "detmat([[cos(theta),-sin(theta),0], ~ ")
	  (insert-return)
	  (professor-insert "        [sin(theta),cos(theta),0], ~ ")
	  (insert-return)
	  (professor-insert "        [0,0,1]], ~ ")
	  (insert-return)
	  (professor-insert "[]) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{detmat} ~ "))

	("Determinant factorise" 
	  (professor-insert "\\\\begin{detmat} ~ ")
	  (insert-return)
	  (professor-insert "detmat([[1-t,2,0], ~ ")
	  (insert-return)
	  (professor-insert "        [1,2-t,0], ~ ")
	  (insert-return)
	  (professor-insert "        [0,0,1-t]], ~ ")
	  (insert-return)
	  (professor-insert "[factor]) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{detmat} ~ "))
	---

	("Inverse dune matrice" 
	  (professor-insert "\\\\begin{invmat} ~ ")
	  (insert-return)
	  (professor-insert "invmat([[a,-b,3], ~ ")
	  (insert-return)
	  (professor-insert "        [1,0,0], ~ ")
	  (insert-return)
	  (professor-insert "        [0,0,1]]) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{invmat} ~ "))
	---

	("Puissance dune matrice" 
	  (professor-insert "\\\\begin{puimat} ~ ")
	  (insert-return)
	  (professor-insert "puimat([[1,1,1], ~ ")
	  (insert-return)
	  (professor-insert "        [1,1,1], ~ ")
	  (insert-return)
	  (professor-insert "        [1,1,1]], ~ ")
	  (insert-return)
	  (professor-insert "5,[]) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{puimat} ~ "))

	("Puissance dune matrice (avec option trigo)" 
	  (professor-insert "\\\\begin{puimat} ~ ")
	  (insert-return)
	  (professor-insert "puimat([[cos(theta),-sin(theta),0], ~ ")
	  (insert-return)
	  (professor-insert "        [sin(theta),cos(theta),0], ~ ")
	  (insert-return)
	  (professor-insert "        [0,0,1]], ~ ")
	  (insert-return)
	  (professor-insert "3,[trigo]) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{puimat} ~ "))

  )

)
