
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : pro-tablor-menu.scm
;; DESCRIPTION : pro-tablor menu
;; COPYRIGHT   : Emmanuel Corcelle (corcelle at gmail dot com)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; BASED ON    : giac-menus.scm
;; COPYRIGHT   : (C) 1999  Bernard Parisse and Joris van der Hoeven
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(texmacs-module (pro-tablor-menu))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Insert professor primitive
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (professor-cursor-pos l)
  (cond ((null? l) 0)
	((null? (cdr l)) 1)
	((and (== (car l) #\() (== (cadr l) #\))) 1)
	((and (== (car l) #\() (== (cadr l) #\,)) 1)
	((and (== (car l) #\,) (== (cadr l) #\))) 1)
	((and (== (car l) #\,) (== (cadr l) #\,)) 1)
	(else (+ (professor-cursor-pos (cdr l)) 1))))

(define (professor-insert s)
  (insert-go-to s (list (professor-cursor-pos (string->list s)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; pro-tablor menu
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(menu-bind pro-tablor-menu

  (->"Tablor"

	("Facteur de reduction (en 1ere position)"
	  (professor-insert "\\\\ech{0.8} ~ ")
	  (insert-return)
	)
	---

	(group "Tableaux de variations")
	
	(->"Tableau standard"
		("avec le signe de la derivee et les variations" 
		  (professor-insert "\\\\begin{TV} ~ ")
		  (insert-return)
	  	  (professor-insert "TV([-infinity,+infinity], [ %<valeurs_interdites>% ], \"f\",\"x\", x^2, 1, n, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TV} ~ "))

		("avec seulement les variations" 
		  (professor-insert "\\\\begin{TV} ~ ")
		  (insert-return)
	  	  (professor-insert "TV([-infinity,+infinity], [ <valeurs_interdites> ], \"f\",\"x\", x^2, 0, n, \\\\tv) ~")
		  (insert-return)
	  	  (professor-insert "\\\\end{TV} ~ "))

		("avec seulement le signe de la derivee" 
		  (professor-insert "\\\\begin{TV} ~ ")
		  (insert-return)
	  	  (professor-insert "TV([-infinity,+infinity], [ <valeurs_interdites> ], \"f\",\"x\", x^2, 2, n, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TV} ~ "))
	)

	(->"Tableau de variation avec zone(s) interdite(s)" 
		("avec le signe de la derivee et les variations"
		  (professor-insert "\\\\begin{TVZ} ~ ")
		  (insert-return)
	  	  (professor-insert "TVZ([-infinity,+infinity], [-1,1,4,6] ,[[-1,1] ,[4 ,6]] ,\"f\",\"x\",ln((x-5)^2-1)+ln(x^2-1), 1, n, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVZ} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites>")
		  (insert-return)
	  	  (professor-insert "<3e_crochet_:_intervalles_exclus> ~"))
		("avec seulement les variations"
		  (professor-insert "\\\\begin{TVZ} ~ ")
		  (insert-return)
	  	  (professor-insert "TVZ([-infinity,+infinity], [-1,1,4,6] ,[[-1,1] ,[4 ,6]] ,\"f\",\"x\",ln((x-5)^2-1)+ln(x^2-1), 0, n, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVZ} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites>")
		  (insert-return)
	  	  (professor-insert "<3e_crochet_:_intervalles_exclus> ~"))
		("avec seulement le signe de la derivee"
		  (professor-insert "\\\\begin{TVZ} ~ ")
		  (insert-return)
	  	  (professor-insert "TVZ([-infinity,+infinity], [-1,1,4,6] ,[[-1,1] ,[4 ,6]] ,\"f\",\"x\",ln((x-5)^2-1)+ln(x^2-1), 2, n, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVZ} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites>")
		  (insert-return)
	  	  (professor-insert "<3e_crochet_:_intervalles_exclus> ~"))
	)

	(->"Tableau des variations avec theoreme des valeurs intermediaires" 
		(group "Pour mettre en evidence les solutions de f(x)=a")
		("avec le signe de la derivee et les variations"
		  (professor-insert "\\\\begin{TVI} ~ ")
		  (insert-return)
	  	  (professor-insert "TVI([ -10,+infinity] ,[-1,1] ,\"f\",\"x\",x^2/(x^2-1), 1, 10, n ,\\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVI} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~"))
		("avec seulement les variations"
		  (professor-insert "\\\\begin{TVI} ~ ")
		  (insert-return)
	  	  (professor-insert "TVI([ -10,+infinity] ,[-1,1] ,\"f\",\"x\",x^2/(x^2-1), 0, 10, n ,\\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVI} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~"))
		("avec seulement le signe de la derivee"
		  (professor-insert "\\\\begin{TVI} ~ ")
		  (insert-return)
	  	  (professor-insert "TVI([ -10,+infinity] ,[-1,1] ,\"f\",\"x\",x^2/(x^2-1), 2, 10, n ,\\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVI} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~"))
	)

	(->"Tableaux de variations avec approximation des zeros de la derivee" 
		("avec le signe de la derivee et les variations"
		  (professor-insert "\\\\begin{TVIapp} ~ ")
		  (insert-return)
	  	  (professor-insert "TVIapp([0,+infinity], [0],\"dg\", \"x\", diff(ln(x)-x*exp(2-x),x), 1, 0, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVIapp}    ~    ")
		  (insert-return)
	  	  (professor-insert "\\\\begin{TVapp*}{201} ~ TVapp([0,+infinity], [0], \"g\", \"x\",ln(x)-x*exp(2-x), 1, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVapp*} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~ "))

		("avec seulement les variations"
		  (professor-insert "\\\\begin{TVIapp} ~ ")
		  (insert-return)
	  	  (professor-insert "TVIapp([0,+infinity], [0],\"g’\", \"x\", diff(ln(x)-x*exp(2-x),x), 0, 0, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVIapp} ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\begin{TVapp*}{201} ~ ")
		  (insert-return)
	  	  (professor-insert "TVapp([0,+infinity], [0], \"g\", \"x\",ln(x)-x*exp(2-x), 1, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVapp*} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~ "))

		("avec seulement le signe de la derivee"
		  (professor-insert "\\\\begin{TVIapp} ~ ")
		  (insert-return)
	  	  (professor-insert "TVIapp([0,+infinity], [0],\"g’\", \"x\", diff(ln(x)-x*exp(2-x),x), 2, 0, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVIapp} ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\begin{TVapp*}{201} ~ TVapp([0,+infinity], [0], \"g\", \"x\",ln(x)-x*exp(2-x), 1, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVapp*} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~ "))
	)

	(->"Tableaux de variations de fonctions prolongeables par continuite" 
		("avec le signe de la derivee et les variations"
		  (professor-insert "\\\\begin{TVPC} ~ ")
		  (insert-return)
	  	  (professor-insert "TVPC([-infinity,+infinity], [0], [0], \"g\", \"t\", e^(-1/x^2) ,1 ,n ,\\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVPC} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_ou_la_fonction_est_prolongee> ~ ")
		  (insert-return)
	  	  (professor-insert "<3e_crochet_:_valeurs_ou_la_fonction_n_est_pas_derivable> ~ "))

		("avec seulement les variations"
		  (professor-insert "\\\\begin{TVPC} ~ ")
		  (insert-return)
	  	  (professor-insert "TVPC([-infinity,+infinity], [0], [0], \"g\", \"t\", e^(-1/x^2) ,0 ,n ,\\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVPC} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_ou_la_fonction_est_prolongee>")
		  (insert-return)
	  	  (professor-insert "<3e_crochet_:_valeurs_ou_la_fonction_n_est_pas_derivable> ~ "))

		("avec seulement le signe de la derivee"
		  (professor-insert "\\\\begin{TVPC} ~ ")
		  (insert-return)
	  	  (professor-insert "TVPC([-infinity,+infinity], [0], [0], \"g\", \"t\", e^(-1/x^2) ,2 ,n ,\\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVPC} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_ou_la_fonction_est_prolongee>")
		  (insert-return)
	  	  (professor-insert "<3e_crochet_:_valeurs_ou_la_fonction_n_est_pas_derivable> ~ "))
	)

	(->"Tableaux de variations et courbes parametrees" 
		("avec le signe de la derivee et les variations"
		  (professor-insert "\\\\begin{TVP} ~ ")
		  (insert-return)
	  	  (professor-insert "TVP(([0,pi/2], [ [],[] ], [\"x\",\"y\"], \"t\", [cos(3*t),sin(4*t)], 1, t, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVP} ~      ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~"))

		("avec seulement les variations"
		  (professor-insert "\\\\begin{TVP} ~ ")
		  (insert-return)
	  	  (professor-insert "TVP(([0,pi/2], [ [],[] ], [\"x\",\"y\"], \"t\", [cos(3*t),sin(4*t)], 0, t, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVP} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~"))

		("avec seulement le signe de la derivee"
		  (professor-insert "\\\\begin{TVP} ~ ")
		  (insert-return)
	  	  (professor-insert "TVP(([0,pi/2], [ [],[] ], [\"x\",\"y\"], \"t\", [cos(3*t),sin(4*t)], 2, t, \\\\tv) ~ ")
		  (insert-return)
	  	  (professor-insert "\\\\end{TVP} ~ ")
		  (insert-return)
	  	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~"))
	)

	---
	(group "Tableaux de signes")

	("Produit de deux facteurs affines" 
	  (professor-insert "\\\\begin{TSa} ~ ")
	  (insert-return)
	  (professor-insert "TSa(-2,3,-1,5,\\\\tv) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{TSa} ~ "))

	("Produit dun nombre qcq de facteurs qcq sur un intervalle qcq" 
	  (professor-insert "\\\\begin{TS} ~ ")
	  (insert-return)
	  (professor-insert "TS(\"P\", [-2*x+3,x^2-1,x^2+1,x-1,x^2-2], [-infinity,+infinity], n, \\\\tv) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{TS} ~ "))

	("Signe dun quotient" 
	  (professor-insert "\\\\begin{TSq} ~ ")
	  (insert-return)
	  (professor-insert "TSq(\"Q\", [-2*x+3,-4*x+5], [x^2-16,x-2], [-infinity,+infinity], n, \\\\tv) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{TSq} ~ "))

	("Signe dune seule expression" 
	  (professor-insert "\\\\begin{TSc} ~ ")
	  (insert-return)
	  (professor-insert "TSc((x+10)/((x-5)*(x-2)), [-10,5], [2,5], n, \\\\tv) ~ ")
	  (insert-return)
	  (professor-insert "\\\\end{TSc} ~ ")
	  (insert-return)
	  (professor-insert "<2e_crochet_:_valeurs_interdites> ~ "))

  )

)
